@@ -1,9 +1,9 @@
 description_version<-function(){
 cat("\n")
 cat("..................................................\n\n")
-cat(" This report was generated using ivivc for R v0.1.7\n")
+cat(" This report was generated using ivivc for R v0.1.8\n")
 cat(" on:-",date(),"\n\n")
-cat(" ivivc dor R was developed by Hsin-ya Lee & Yung-jin Lee.\n")
+cat(" ivivc for R was developed by Hsin-ya Lee & Yung-jin Lee.\n")
 cat(" contact: Yung-jin Lee <mobilepk@gmail.com> \n")
 cat(" Kaohsiung Veterans General Hospital (HY) &\n")
 cat(" ptpc inc. (YJ),\n")
