@@ -3,10 +3,10 @@ run<-function()
 {
 options(warn=-1)
  
-  if (noquote(unlist(format(.Platform)))[1] == "unix") {
-        windows <<- function(record) {
-        }
-     }   
+###   if (noquote(unlist(format(.Platform)))[1] == "unix") {
+###         windows <<- function(record) {
+###         }
+###      }   
   cat("\n")
   file.menu <- c("Start a new project",
                  "Tutorial (Wagner-Nelson method)", 
