@@ -6,7 +6,8 @@
 packageStartupMessage("
 .....................................................................
 
-  ivivc for R v0.1.7                                                 
+  ivivc for R 
+  v0.1.8                                              
                                                                      
   In vitro-in vivo correlation (IVIVC) is defined as the correlation 
   between in-vitro drug dissolution and in-vivo drug absorption.     
